/********************************************************************************
** Form generated from reading UI file 'OptionsWidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_OPTIONSWIDGET_H
#define UI_OPTIONSWIDGET_H

#include <CollapsibleGroupBox.h>
#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QToolButton>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

namespace fix_orientation {

class Ui_OptionsWidget
{
public:
    QVBoxLayout *vboxLayout;
    CollapsibleGroupBox *rotateGroupBox;
    QVBoxLayout *vboxLayout1;
    QHBoxLayout *hboxLayout;
    QSpacerItem *spacerItem;
    QToolButton *rotateLeftBtn;
    QToolButton *rotateRightBtn;
    QSpacerItem *spacerItem1;
    QHBoxLayout *hboxLayout1;
    QSpacerItem *spacerItem2;
    QLabel *rotationIndicator;
    QSpacerItem *spacerItem3;
    QHBoxLayout *hboxLayout2;
    QSpacerItem *spacerItem4;
    QPushButton *resetBtn;
    QSpacerItem *spacerItem5;
    CollapsibleGroupBox *trimGroupBox;
    QVBoxLayout *vboxLayout2;
    QCheckBox *trimEnabledCheck;
    QGridLayout *trimGridLayout;
    QLabel *labelTrimTopLeft;
    QSpinBox *trimTopSpin;
    QLabel *labelTrimTopRight;
    QSpinBox *trimLeftSpin;
    QLabel *labelTrimCenter;
    QSpinBox *trimRightSpin;
    QLabel *labelTrimBottomLeft;
    QSpinBox *trimBottomSpin;
    QLabel *labelTrimBottomRight;
    QPushButton *resetTrimBtn;
    QHBoxLayout *hboxLayout3;
    QSpacerItem *spacerItem6;
    QPushButton *applyToBtn;
    QSpacerItem *spacerItem7;
    QSpacerItem *spacerItem8;

    void setupUi(QWidget *fix_orientation__OptionsWidget)
    {
        if (fix_orientation__OptionsWidget->objectName().isEmpty())
            fix_orientation__OptionsWidget->setObjectName("fix_orientation__OptionsWidget");
        fix_orientation__OptionsWidget->resize(220, 340);
        vboxLayout = new QVBoxLayout(fix_orientation__OptionsWidget);
        vboxLayout->setObjectName("vboxLayout");
        rotateGroupBox = new CollapsibleGroupBox(fix_orientation__OptionsWidget);
        rotateGroupBox->setObjectName("rotateGroupBox");
        rotateGroupBox->setAlignment(Qt::AlignCenter);
        vboxLayout1 = new QVBoxLayout(rotateGroupBox);
        vboxLayout1->setObjectName("vboxLayout1");
        hboxLayout = new QHBoxLayout();
        hboxLayout->setObjectName("hboxLayout");
        spacerItem = new QSpacerItem(1, 1, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        hboxLayout->addItem(spacerItem);

        rotateLeftBtn = new QToolButton(rotateGroupBox);
        rotateLeftBtn->setObjectName("rotateLeftBtn");
        QIcon icon;
        icon.addFile(QString::fromUtf8(":/icons/object-rotate-left.svg"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        rotateLeftBtn->setIcon(icon);
        rotateLeftBtn->setIconSize(QSize(24, 24));

        hboxLayout->addWidget(rotateLeftBtn);

        rotateRightBtn = new QToolButton(rotateGroupBox);
        rotateRightBtn->setObjectName("rotateRightBtn");
        QIcon icon1;
        icon1.addFile(QString::fromUtf8(":/icons/object-rotate-right.svg"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        rotateRightBtn->setIcon(icon1);
        rotateRightBtn->setIconSize(QSize(24, 24));

        hboxLayout->addWidget(rotateRightBtn);

        spacerItem1 = new QSpacerItem(1, 1, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        hboxLayout->addItem(spacerItem1);


        vboxLayout1->addLayout(hboxLayout);

        hboxLayout1 = new QHBoxLayout();
        hboxLayout1->setObjectName("hboxLayout1");
        spacerItem2 = new QSpacerItem(1, 1, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        hboxLayout1->addItem(spacerItem2);

        rotationIndicator = new QLabel(rotateGroupBox);
        rotationIndicator->setObjectName("rotationIndicator");
        rotationIndicator->setPixmap(QPixmap(QString::fromUtf8(":/icons/big-up-arrow.svg")));

        hboxLayout1->addWidget(rotationIndicator);

        spacerItem3 = new QSpacerItem(1, 1, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        hboxLayout1->addItem(spacerItem3);


        vboxLayout1->addLayout(hboxLayout1);

        hboxLayout2 = new QHBoxLayout();
        hboxLayout2->setObjectName("hboxLayout2");
        spacerItem4 = new QSpacerItem(1, 1, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        hboxLayout2->addItem(spacerItem4);

        resetBtn = new QPushButton(rotateGroupBox);
        resetBtn->setObjectName("resetBtn");

        hboxLayout2->addWidget(resetBtn);

        spacerItem5 = new QSpacerItem(1, 1, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        hboxLayout2->addItem(spacerItem5);


        vboxLayout1->addLayout(hboxLayout2);


        vboxLayout->addWidget(rotateGroupBox);

        trimGroupBox = new CollapsibleGroupBox(fix_orientation__OptionsWidget);
        trimGroupBox->setObjectName("trimGroupBox");
        trimGroupBox->setAlignment(Qt::AlignCenter);
        vboxLayout2 = new QVBoxLayout(trimGroupBox);
        vboxLayout2->setObjectName("vboxLayout2");
        trimEnabledCheck = new QCheckBox(trimGroupBox);
        trimEnabledCheck->setObjectName("trimEnabledCheck");

        vboxLayout2->addWidget(trimEnabledCheck);

        trimGridLayout = new QGridLayout();
        trimGridLayout->setObjectName("trimGridLayout");
        labelTrimTopLeft = new QLabel(trimGroupBox);
        labelTrimTopLeft->setObjectName("labelTrimTopLeft");
        labelTrimTopLeft->setText(QString::fromUtf8("|="));
        labelTrimTopLeft->setAlignment(Qt::AlignRight|Qt::AlignVCenter);

        trimGridLayout->addWidget(labelTrimTopLeft, 0, 0, 1, 1);

        trimTopSpin = new QSpinBox(trimGroupBox);
        trimTopSpin->setObjectName("trimTopSpin");
        trimTopSpin->setMinimum(0);

        trimGridLayout->addWidget(trimTopSpin, 0, 1, 1, 1);

        labelTrimTopRight = new QLabel(trimGroupBox);
        labelTrimTopRight->setObjectName("labelTrimTopRight");
        labelTrimTopRight->setText(QString::fromUtf8("=|"));
        labelTrimTopRight->setAlignment(Qt::AlignLeft|Qt::AlignVCenter);

        trimGridLayout->addWidget(labelTrimTopRight, 0, 2, 1, 1);

        trimLeftSpin = new QSpinBox(trimGroupBox);
        trimLeftSpin->setObjectName("trimLeftSpin");
        trimLeftSpin->setMinimum(0);

        trimGridLayout->addWidget(trimLeftSpin, 1, 0, 1, 1);

        labelTrimCenter = new QLabel(trimGroupBox);
        labelTrimCenter->setObjectName("labelTrimCenter");
        labelTrimCenter->setText(QString::fromUtf8("-|-"));
        labelTrimCenter->setAlignment(Qt::AlignCenter);

        trimGridLayout->addWidget(labelTrimCenter, 1, 1, 1, 1);

        trimRightSpin = new QSpinBox(trimGroupBox);
        trimRightSpin->setObjectName("trimRightSpin");
        trimRightSpin->setMinimum(0);

        trimGridLayout->addWidget(trimRightSpin, 1, 2, 1, 1);

        labelTrimBottomLeft = new QLabel(trimGroupBox);
        labelTrimBottomLeft->setObjectName("labelTrimBottomLeft");
        labelTrimBottomLeft->setText(QString::fromUtf8("|___"));
        labelTrimBottomLeft->setAlignment(Qt::AlignRight|Qt::AlignVCenter);

        trimGridLayout->addWidget(labelTrimBottomLeft, 2, 0, 1, 1);

        trimBottomSpin = new QSpinBox(trimGroupBox);
        trimBottomSpin->setObjectName("trimBottomSpin");
        trimBottomSpin->setMinimum(0);

        trimGridLayout->addWidget(trimBottomSpin, 2, 1, 1, 1);

        labelTrimBottomRight = new QLabel(trimGroupBox);
        labelTrimBottomRight->setObjectName("labelTrimBottomRight");
        labelTrimBottomRight->setText(QString::fromUtf8("___|"));
        labelTrimBottomRight->setAlignment(Qt::AlignLeft|Qt::AlignVCenter);

        trimGridLayout->addWidget(labelTrimBottomRight, 2, 2, 1, 1);


        vboxLayout2->addLayout(trimGridLayout);

        resetTrimBtn = new QPushButton(trimGroupBox);
        resetTrimBtn->setObjectName("resetTrimBtn");

        vboxLayout2->addWidget(resetTrimBtn);


        vboxLayout->addWidget(trimGroupBox);

        hboxLayout3 = new QHBoxLayout();
        hboxLayout3->setObjectName("hboxLayout3");
        spacerItem6 = new QSpacerItem(1, 1, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        hboxLayout3->addItem(spacerItem6);

        applyToBtn = new QPushButton(fix_orientation__OptionsWidget);
        applyToBtn->setObjectName("applyToBtn");

        hboxLayout3->addWidget(applyToBtn);

        spacerItem7 = new QSpacerItem(1, 1, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        hboxLayout3->addItem(spacerItem7);


        vboxLayout->addLayout(hboxLayout3);

        spacerItem8 = new QSpacerItem(1, 1, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        vboxLayout->addItem(spacerItem8);


        retranslateUi(fix_orientation__OptionsWidget);

        QMetaObject::connectSlotsByName(fix_orientation__OptionsWidget);
    } // setupUi

    void retranslateUi(QWidget *fix_orientation__OptionsWidget)
    {
        fix_orientation__OptionsWidget->setWindowTitle(QCoreApplication::translate("fix_orientation::OptionsWidget", "Form", nullptr));
        rotateGroupBox->setTitle(QCoreApplication::translate("fix_orientation::OptionsWidget", "Rotate", nullptr));
        rotateLeftBtn->setText(QCoreApplication::translate("fix_orientation::OptionsWidget", "...", nullptr));
        rotateRightBtn->setText(QCoreApplication::translate("fix_orientation::OptionsWidget", "...", nullptr));
        rotationIndicator->setText(QString());
        resetBtn->setText(QCoreApplication::translate("fix_orientation::OptionsWidget", "Reset", nullptr));
        trimGroupBox->setTitle(QCoreApplication::translate("fix_orientation::OptionsWidget", "Crop scan (trim)", nullptr));
        trimEnabledCheck->setText(QCoreApplication::translate("fix_orientation::OptionsWidget", "Enable manual trim", nullptr));
        resetTrimBtn->setText(QCoreApplication::translate("fix_orientation::OptionsWidget", "Reset trim", nullptr));
        applyToBtn->setText(QCoreApplication::translate("fix_orientation::OptionsWidget", "Apply to ...", nullptr));
    } // retranslateUi

};

} // namespace fix_orientation

namespace fix_orientation {
namespace Ui {
    class OptionsWidget: public Ui_OptionsWidget {};
} // namespace Ui
} // namespace fix_orientation

#endif // UI_OPTIONSWIDGET_H
