/********************************************************************************
** Form generated from reading UI file 'ApplyDialog.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_APPLYDIALOG_H
#define UI_APPLYDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>

namespace deskew {

class Ui_ApplyDialog
{
public:
    QVBoxLayout *verticalLayout_3;
    QGroupBox *groupBox_2;
    QVBoxLayout *verticalLayout_2;
    QRadioButton *thisPageRB;
    QRadioButton *allPagesRB;
    QRadioButton *thisPageAndFollowersRB;
    QRadioButton *thisEveryOtherRB;
    QRadioButton *everyOtherRB;
    QRadioButton *selectedPagesRB;
    QHBoxLayout *horizontalLayout_2;
    QSpacerItem *horizontalSpacer_7;
    QLabel *selectedPagesHint;
    QRadioButton *everyOtherSelectedRB;
    QHBoxLayout *horizontalLayout;
    QSpacerItem *horizontalSpacer_6;
    QLabel *everyOtherSelectedHint;
    QGroupBox *applyPartsGroupBox;
    QVBoxLayout *verticalLayout_apply_parts;
    QCheckBox *applyDeskewCheckBox;
    QCheckBox *applyObliqueCheckBox;
    QSpacerItem *verticalSpacer;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *deskew__ApplyDialog)
    {
        if (deskew__ApplyDialog->objectName().isEmpty())
            deskew__ApplyDialog->setObjectName("deskew__ApplyDialog");
        deskew__ApplyDialog->setWindowModality(Qt::WindowModal);
        deskew__ApplyDialog->resize(355, 307);
        verticalLayout_3 = new QVBoxLayout(deskew__ApplyDialog);
        verticalLayout_3->setObjectName("verticalLayout_3");
        groupBox_2 = new QGroupBox(deskew__ApplyDialog);
        groupBox_2->setObjectName("groupBox_2");
        verticalLayout_2 = new QVBoxLayout(groupBox_2);
        verticalLayout_2->setObjectName("verticalLayout_2");
        thisPageRB = new QRadioButton(groupBox_2);
        thisPageRB->setObjectName("thisPageRB");
        thisPageRB->setChecked(true);

        verticalLayout_2->addWidget(thisPageRB);

        allPagesRB = new QRadioButton(groupBox_2);
        allPagesRB->setObjectName("allPagesRB");

        verticalLayout_2->addWidget(allPagesRB);

        thisPageAndFollowersRB = new QRadioButton(groupBox_2);
        thisPageAndFollowersRB->setObjectName("thisPageAndFollowersRB");

        verticalLayout_2->addWidget(thisPageAndFollowersRB);

        thisEveryOtherRB = new QRadioButton(groupBox_2);
        thisEveryOtherRB->setObjectName("thisEveryOtherRB");

        verticalLayout_2->addWidget(thisEveryOtherRB);

        everyOtherRB = new QRadioButton(groupBox_2);
        everyOtherRB->setObjectName("everyOtherRB");

        verticalLayout_2->addWidget(everyOtherRB);

        selectedPagesRB = new QRadioButton(groupBox_2);
        selectedPagesRB->setObjectName("selectedPagesRB");

        verticalLayout_2->addWidget(selectedPagesRB);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        horizontalSpacer_7 = new QSpacerItem(30, 13, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer_7);

        selectedPagesHint = new QLabel(groupBox_2);
        selectedPagesHint->setObjectName("selectedPagesHint");
        QFont font;
        font.setPointSize(7);
        selectedPagesHint->setFont(font);

        horizontalLayout_2->addWidget(selectedPagesHint);


        verticalLayout_2->addLayout(horizontalLayout_2);

        everyOtherSelectedRB = new QRadioButton(groupBox_2);
        everyOtherSelectedRB->setObjectName("everyOtherSelectedRB");

        verticalLayout_2->addWidget(everyOtherSelectedRB);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        horizontalSpacer_6 = new QSpacerItem(30, 13, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer_6);

        everyOtherSelectedHint = new QLabel(groupBox_2);
        everyOtherSelectedHint->setObjectName("everyOtherSelectedHint");
        everyOtherSelectedHint->setFont(font);

        horizontalLayout->addWidget(everyOtherSelectedHint);


        verticalLayout_2->addLayout(horizontalLayout);


        verticalLayout_3->addWidget(groupBox_2);

        applyPartsGroupBox = new QGroupBox(deskew__ApplyDialog);
        applyPartsGroupBox->setObjectName("applyPartsGroupBox");
        verticalLayout_apply_parts = new QVBoxLayout(applyPartsGroupBox);
        verticalLayout_apply_parts->setObjectName("verticalLayout_apply_parts");
        applyDeskewCheckBox = new QCheckBox(applyPartsGroupBox);
        applyDeskewCheckBox->setObjectName("applyDeskewCheckBox");
        applyDeskewCheckBox->setChecked(true);

        verticalLayout_apply_parts->addWidget(applyDeskewCheckBox);

        applyObliqueCheckBox = new QCheckBox(applyPartsGroupBox);
        applyObliqueCheckBox->setObjectName("applyObliqueCheckBox");
        applyObliqueCheckBox->setChecked(true);

        verticalLayout_apply_parts->addWidget(applyObliqueCheckBox);


        verticalLayout_3->addWidget(applyPartsGroupBox);

        verticalSpacer = new QSpacerItem(20, 0, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_3->addItem(verticalSpacer);

        buttonBox = new QDialogButtonBox(deskew__ApplyDialog);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        verticalLayout_3->addWidget(buttonBox);


        retranslateUi(deskew__ApplyDialog);
        QObject::connect(buttonBox, &QDialogButtonBox::rejected, deskew__ApplyDialog, qOverload<>(&QDialog::reject));

        QMetaObject::connectSlotsByName(deskew__ApplyDialog);
    } // setupUi

    void retranslateUi(QDialog *deskew__ApplyDialog)
    {
        groupBox_2->setTitle(QCoreApplication::translate("deskew::ApplyDialog", "Apply to", nullptr));
        thisPageRB->setText(QCoreApplication::translate("deskew::ApplyDialog", "This page only (already applied)", nullptr));
        allPagesRB->setText(QCoreApplication::translate("deskew::ApplyDialog", "All pages", nullptr));
        thisPageAndFollowersRB->setText(QCoreApplication::translate("deskew::ApplyDialog", "This page and the following ones", nullptr));
        thisEveryOtherRB->setText(QCoreApplication::translate("deskew::ApplyDialog", "This page and the following every other page", nullptr));
        everyOtherRB->setText(QCoreApplication::translate("deskew::ApplyDialog", "Every other page", nullptr));
        selectedPagesRB->setText(QCoreApplication::translate("deskew::ApplyDialog", "Selected pages", nullptr));
        selectedPagesHint->setText(QCoreApplication::translate("deskew::ApplyDialog", "Use Ctrl+Click / Shift+Click to select multiple pages.", nullptr));
        everyOtherSelectedRB->setText(QCoreApplication::translate("deskew::ApplyDialog", "Every other selected page", nullptr));
        everyOtherSelectedHint->setText(QCoreApplication::translate("deskew::ApplyDialog", "The current page will be included.", nullptr));
        applyPartsGroupBox->setTitle(QCoreApplication::translate("deskew::ApplyDialog", "Apply parameters", nullptr));
        applyDeskewCheckBox->setText(QCoreApplication::translate("deskew::ApplyDialog", "Deskew angle and mode", nullptr));
        applyObliqueCheckBox->setText(QCoreApplication::translate("deskew::ApplyDialog", "Oblique angle and mode", nullptr));
        (void)deskew__ApplyDialog;
    } // retranslateUi

};

} // namespace deskew

namespace deskew {
namespace Ui {
    class ApplyDialog: public Ui_ApplyDialog {};
} // namespace Ui
} // namespace deskew

#endif // UI_APPLYDIALOG_H
