/****************************************************************************
** Meta object code from reading C++ file 'OptionsWidgetBinarizationSauvola.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../../scantailor-advanced-1.2.1/src/core/filters/output/OptionsWidgetBinarizationSauvola.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'OptionsWidgetBinarizationSauvola.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN6output32OptionsWidgetBinarizationSauvolaE_t {};
} // unnamed namespace

template <> constexpr inline auto output::OptionsWidgetBinarizationSauvola::qt_create_metaobjectdata<qt_meta_tag_ZN6output32OptionsWidgetBinarizationSauvolaE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "output::OptionsWidgetBinarizationSauvola",
        "sauvolaDeltaChanged",
        "",
        "value",
        "windowSizeChanged",
        "sauvolaCoefChanged",
        "sendStateChanged"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'sauvolaDeltaChanged'
        QtMocHelpers::SlotData<void(double)>(1, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Double, 3 },
        }}),
        // Slot 'windowSizeChanged'
        QtMocHelpers::SlotData<void(int)>(4, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 3 },
        }}),
        // Slot 'sauvolaCoefChanged'
        QtMocHelpers::SlotData<void(double)>(5, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Double, 3 },
        }}),
        // Slot 'sendStateChanged'
        QtMocHelpers::SlotData<void()>(6, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<OptionsWidgetBinarizationSauvola, qt_meta_tag_ZN6output32OptionsWidgetBinarizationSauvolaE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject output::OptionsWidgetBinarizationSauvola::staticMetaObject = { {
    QMetaObject::SuperData::link<OptionsWidgetBinarization::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6output32OptionsWidgetBinarizationSauvolaE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6output32OptionsWidgetBinarizationSauvolaE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6output32OptionsWidgetBinarizationSauvolaE_t>.metaTypes,
    nullptr
} };

void output::OptionsWidgetBinarizationSauvola::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<OptionsWidgetBinarizationSauvola *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->sauvolaDeltaChanged((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 1: _t->windowSizeChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 2: _t->sauvolaCoefChanged((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 3: _t->sendStateChanged(); break;
        default: ;
        }
    }
}

const QMetaObject *output::OptionsWidgetBinarizationSauvola::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *output::OptionsWidgetBinarizationSauvola::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6output32OptionsWidgetBinarizationSauvolaE_t>.strings))
        return static_cast<void*>(this);
    return OptionsWidgetBinarization::qt_metacast(_clname);
}

int output::OptionsWidgetBinarizationSauvola::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = OptionsWidgetBinarization::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 4)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 4;
    }
    return _id;
}
QT_WARNING_POP
