/****************************************************************************
** Meta object code from reading C++ file 'ImageView.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../../scantailor-advanced-1.2.1/src/core/filters/page_layout/ImageView.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'ImageView.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN11page_layout9ImageViewE_t {};
} // unnamed namespace

template <> constexpr inline auto page_layout::ImageView::qt_create_metaobjectdata<qt_meta_tag_ZN11page_layout9ImageViewE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "page_layout::ImageView",
        "invalidateThumbnail",
        "",
        "PageId",
        "pageId",
        "invalidateAllThumbnails",
        "marginsSetLocally",
        "Margins",
        "marginsMm",
        "marginsSetExternally",
        "leftRightLinkToggled",
        "linked",
        "topBottomLinkToggled",
        "alignmentChanged",
        "Alignment",
        "alignment",
        "aggregateHardSizeChanged"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'invalidateThumbnail'
        QtMocHelpers::SignalData<void(const PageId &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'invalidateAllThumbnails'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'marginsSetLocally'
        QtMocHelpers::SignalData<void(const Margins &)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 8 },
        }}),
        // Slot 'marginsSetExternally'
        QtMocHelpers::SlotData<void(const Margins &)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 8 },
        }}),
        // Slot 'leftRightLinkToggled'
        QtMocHelpers::SlotData<void(bool)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 11 },
        }}),
        // Slot 'topBottomLinkToggled'
        QtMocHelpers::SlotData<void(bool)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 11 },
        }}),
        // Slot 'alignmentChanged'
        QtMocHelpers::SlotData<void(const Alignment &)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 14, 15 },
        }}),
        // Slot 'aggregateHardSizeChanged'
        QtMocHelpers::SlotData<void()>(16, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ImageView, qt_meta_tag_ZN11page_layout9ImageViewE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject page_layout::ImageView::staticMetaObject = { {
    QMetaObject::SuperData::link<ImageViewBase::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11page_layout9ImageViewE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11page_layout9ImageViewE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN11page_layout9ImageViewE_t>.metaTypes,
    nullptr
} };

void page_layout::ImageView::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ImageView *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->invalidateThumbnail((*reinterpret_cast<std::add_pointer_t<PageId>>(_a[1]))); break;
        case 1: _t->invalidateAllThumbnails(); break;
        case 2: _t->marginsSetLocally((*reinterpret_cast<std::add_pointer_t<Margins>>(_a[1]))); break;
        case 3: _t->marginsSetExternally((*reinterpret_cast<std::add_pointer_t<Margins>>(_a[1]))); break;
        case 4: _t->leftRightLinkToggled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 5: _t->topBottomLinkToggled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 6: _t->alignmentChanged((*reinterpret_cast<std::add_pointer_t<Alignment>>(_a[1]))); break;
        case 7: _t->aggregateHardSizeChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ImageView::*)(const PageId & )>(_a, &ImageView::invalidateThumbnail, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (ImageView::*)()>(_a, &ImageView::invalidateAllThumbnails, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (ImageView::*)(const Margins & )>(_a, &ImageView::marginsSetLocally, 2))
            return;
    }
}

const QMetaObject *page_layout::ImageView::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *page_layout::ImageView::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11page_layout9ImageViewE_t>.strings))
        return static_cast<void*>(this);
    return ImageViewBase::qt_metacast(_clname);
}

int page_layout::ImageView::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ImageViewBase::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 8)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 8;
    }
    return _id;
}

// SIGNAL 0
void page_layout::ImageView::invalidateThumbnail(const PageId & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void page_layout::ImageView::invalidateAllThumbnails()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void page_layout::ImageView::marginsSetLocally(const Margins & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}
QT_WARNING_POP
